@@ -56,11 +56,11 @@
 /**
  * xsltParseStylesheetImport:
  * @style:  the XSLT stylesheet
- * @template:  the "strip-space" element
+ * @cur:  the import element
  *
- * parse an XSLT stylesheet strip-space element and record
- * elements needing stripping. Returns zero on success and something else
- * on failure.
+ * parse an XSLT stylesheet import element
+ *
+ * Returns 0 in case of success -1 in case of failure.
  */
 
 int
@@ -114,7 +114,7 @@ xsltParseStylesheetImport(xsltStylesheetPtr style, xmlNodePtr cur) {
 	goto error;
     }
 
-    res = xsltParseStylesheetDoc(import);
+    res = xsltParseStylesheetImportedDoc(import);
     if (res != NULL) {
 	res->parent = style;
 	res->next = style->imports;
@@ -139,11 +139,11 @@ error:
 /**
  * xsltParseStylesheetInclude:
  * @style:  the XSLT stylesheet
- * @template:  the "strip-space" element
+ * @cur:  the include node
  *
- * parse an XSLT stylesheet strip-space element and record
- * elements needing stripping. Returns zero on success, something else
- * on failure.
+ * parse an XSLT stylesheet include element
+ *
+ * Returns 0 in case of success -1 in case of failure
  */
 
 int
@@ -230,7 +230,7 @@ xsltNextImport(xsltStylesheetPtr cur) {
  * xsltNeedElemSpaceHandling:
  * @ctxt:  an XSLT transformation context
  *
- * Returns whether that stylesheet requires white-space stripping
+ * Checks whether that stylesheet requires white-space stripping
  *
  * Returns 1 if space should be stripped, 0 if not
  */
@@ -284,9 +284,9 @@ xsltFindElemSpaceHandling(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 	    if (xmlStrEqual(val, (xmlChar *) "preserve"))
 		return(0);
 	} 
-	if (ctxt->style->stripAll == 1)
+	if (style->stripAll == 1)
 	    return(1);
-	if (ctxt->style->stripAll == -1)
+	if (style->stripAll == -1)
 	    return(0);
 
 	style = xsltNextImport(style);
