@@ -46,6 +46,13 @@
 #endif /* _MS_VER */
 #endif /* WIN32 */
 
+#ifdef XSLT_NEED_TRIO
+#include "trio.h"
+#ifdef __VMS 
+# define vsnprintf trio_vsnprintf
+#endif
+#endif
+
 /************************************************************************
  * 									*
  * 			Convenience function				*
@@ -254,10 +261,6 @@ xsltMessage(xsltTransformContextPtr ctxt, xmlNodePtr node, xmlNodePtr inst) {
  * 									*
  ************************************************************************/
 
-#ifdef XSLT_NEED_TRIO
-#define vsnprintf trio_vsnprintf
-#endif
-
 #define XSLT_GET_VAR_STR(msg, str) {				\
     int       size;						\
     int       chars;						\
@@ -476,6 +479,8 @@ xsltSetTransformErrorFunc(xsltTransformContextPtr ctxt,
 /**
  * xsltTransformError:
  * @ctxt:  an XSLT transformation context
+ * @style:  the XSLT stylesheet used
+ * @node:  the current node in the stylesheet
  * @msg:  the message to display/transmit
  * @...:  extra parameters for the message display
  *
@@ -631,12 +636,14 @@ xsltDocumentSortFunction(xmlNodeSetPtr list) {
 /**
  * xsltComputeSortResult:
  * @ctxt:  a XSLT process context
- * @sorts:  array of sort nodes
+ * @sort:  node list
  *
  * reorder the current node list accordingly to the set of sorting
  * requirement provided by the array of nodes.
+ *
+ * Returns a ordered XPath nodeset or NULL in case of error.
  */
-static xmlXPathObjectPtr *
+xmlXPathObjectPtr *
 xsltComputeSortResult(xsltTransformContextPtr ctxt, xmlNodePtr sort) {
     xmlXPathObjectPtr *results = NULL;
     xmlNodeSetPtr list = NULL;
@@ -735,7 +742,7 @@ xsltComputeSortResult(xsltTransformContextPtr ctxt, xmlNodePtr sort) {
 }
 
 /**
- * xsltDoSortFunction:
+ * xsltDefaultSortFunction:
  * @ctxt:  a XSLT process context
  * @sorts:  array of sort nodes
  * @nbsorts:  the number of sorts in the array
@@ -744,7 +751,7 @@ xsltComputeSortResult(xsltTransformContextPtr ctxt, xmlNodePtr sort) {
  * requirement provided by the arry of nodes.
  */
 void	
-xsltDoSortFunction(xsltTransformContextPtr ctxt, xmlNodePtr *sorts,
+xsltDefaultSortFunction(xsltTransformContextPtr ctxt, xmlNodePtr *sorts,
 	           int nbsorts) {
     xmlXPathObjectPtr *resultsTab[XSLT_MAX_SORT];
     xmlXPathObjectPtr *results = NULL, *res;
@@ -955,6 +962,63 @@ xsltDoSortFunction(xsltTransformContextPtr ctxt, xmlNodePtr *sorts,
     }
 }
 
+
+static xsltSortFunc xsltSortFunction = xsltDefaultSortFunction;
+
+/**
+ * xsltDoSortFunction:
+ * @ctxt:  a XSLT process context
+ * @sorts:  array of sort nodes
+ * @nbsorts:  the number of sorts in the array
+ *
+ * reorder the current node list accordingly to the set of sorting
+ * requirement provided by the arry of nodes.
+ * This is a wrapper function, the actual function used is specified
+ * using xsltSetCtxtSortFunc() to set the context specific sort function,
+ * or xsltSetSortFunc() to set the global sort function.
+ * If a sort function is set on the context, this will get called.
+ * Otherwise the global sort function is called.
+ */
+void
+xsltDoSortFunction(xsltTransformContextPtr ctxt, xmlNodePtr * sorts,
+                   int nbsorts)
+{
+    if (ctxt->sortfunc != NULL)
+	(ctxt->sortfunc)(ctxt, sorts, nbsorts);
+    else if (xsltSortFunction != NULL)
+        xsltSortFunction(ctxt, sorts, nbsorts);
+}
+
+/**
+ * xsltSetSortFunc:
+ * @handler:  the new handler function
+ *
+ * Function to reset the global handler for XSLT sorting.
+ * If the handler is NULL, the default sort function will be used.
+ */
+void
+xsltSetSortFunc(xsltSortFunc handler) {
+    if (handler != NULL)
+	xsltSortFunction = handler;
+    else
+	xsltSortFunction = xsltDefaultSortFunction;
+}
+
+/**
+ * xsltSetCtxtSortFunc:
+ * @ctxt:  a XSLT process context
+ * @handler:  the new handler function
+ *
+ * Function to set the handler for XSLT sorting
+ * for the specified context. 
+ * If the handler is NULL, then the global
+ * sort function will be called
+ */
+void 
+xsltSetCtxtSortFunc(xsltTransformContextPtr ctxt, xsltSortFunc handler) {
+    ctxt->sortfunc = handler;
+}
+
 /************************************************************************
  * 									*
  * 				Output					*
@@ -1017,7 +1081,7 @@ xsltSaveResultTo(xmlOutputBufferPtr buf, xmlDocPtr result,
 	} else {
 	    htmlSetMetaEncoding(result, (const xmlChar *) "UTF-8");
 	}
-	if (indent != 0)
+	if (indent == -1)
 	    indent = 1;
 	htmlDocContentDumpFormatOutput(buf, result, (const char *) encoding,
 		                       indent);
@@ -1264,7 +1328,6 @@ xsltSaveResultToFd(int fd, xmlDocPtr result, xsltStylesheetPtr style) {
  * @doc_txt_len:  Length of the generated XML text
  * @result:  the result xmlDocPtr
  * @style:  the stylesheet
- * @compression:  the compression factor (0 - 9 included)
  *
  * Save the result @result obtained by applying the @style stylesheet
  * to a file or @URL
@@ -1512,6 +1575,123 @@ xsltSaveProfiling(xsltTransformContextPtr ctxt, FILE *output) {
     xmlFree(templates);
 }
 
+/************************************************************************
+ * 									*
+ * 		Fetching profiling informations				*
+ * 									*
+ ************************************************************************/
+
+/**
+ * xsltGetProfileInformation:
+ * @ctxt:  a transformation context
+ *
+ * This function should be called after the transformation completed
+ * to extract template processing profiling informations if availble.
+ * The informations are returned as an XML document tree like
+ * <?xml version="1.0"?>
+ * <profile>
+ * <template rank="1" match="*" name=""
+ *         mode="" calls="6" time="48" average="8"/>
+ * <template rank="2" match="item2|item3" name=""
+ *         mode="" calls="10" time="30" average="3"/>
+ * <template rank="3" match="item1" name=""
+ *         mode="" calls="5" time="17" average="3"/>
+ * </profile>
+ * The caller will need to free up the returned tree with xmlFreeDoc()
+ *
+ * Returns the xmlDocPtr corresponding to the result or NULL if not available.
+ */
+
+xmlDocPtr
+xsltGetProfileInformation(xsltTransformContextPtr ctxt)
+{
+    xmlDocPtr ret = NULL;
+    xmlNodePtr root, child;
+    char buf[100];
+
+    xsltStylesheetPtr style;
+    xsltTemplatePtr *templates;
+    xsltTemplatePtr templ;
+    int nb = 0, max = 0, i, j, total, totalt;
+
+    if (!ctxt)
+        return NULL;
+
+    if (!ctxt->profile)
+        return NULL;
+
+    nb = 0;
+    max = 10000;
+    templates =
+        (xsltTemplatePtr *) xmlMalloc(max * sizeof(xsltTemplatePtr));
+    if (templates == NULL)
+        return NULL;
+
+    /*
+     * collect all the templates in an array
+     */
+    style = ctxt->style;
+    while (style != NULL) {
+        templ = style->templates;
+        while (templ != NULL) {
+            if (nb >= max)
+                break;
+
+            if (templ->nbCalls > 0)
+                templates[nb++] = templ;
+            templ = templ->next;
+        }
+
+        style = (xsltStylesheetPtr) xsltNextImport(style);
+    }
+
+    /*
+     * Sort the array by time spent
+     */
+    for (i = 0; i < nb - 1; i++) {
+        for (j = i + 1; j < nb; j++) {
+            if ((templates[i]->time <= templates[j]->time) ||
+                ((templates[i]->time == templates[j]->time) &&
+                 (templates[i]->nbCalls <= templates[j]->nbCalls))) {
+                templ = templates[j];
+                templates[j] = templates[i];
+                templates[i] = templ;
+            }
+        }
+    }
+
+    /*
+     * Generate a document corresponding to the results.
+     */
+    ret = xmlNewDoc(BAD_CAST "1.0");
+    root = xmlNewDocNode(ret, NULL, BAD_CAST "profile", NULL);
+    xmlDocSetRootElement(ret, root);
+
+    total = 0;
+    totalt = 0;
+    for (i = 0; i < nb; i++) {
+        child = xmlNewChild(root, NULL, BAD_CAST "template", NULL);
+        sprintf(buf, "%d", i + 1);
+        xmlSetProp(child, BAD_CAST "rank", BAD_CAST buf);
+        xmlSetProp(child, BAD_CAST "match", BAD_CAST templates[i]->match);
+        xmlSetProp(child, BAD_CAST "name", BAD_CAST templates[i]->name);
+        xmlSetProp(child, BAD_CAST "mode", BAD_CAST templates[i]->mode);
+
+        sprintf(buf, "%d", templates[i]->nbCalls);
+        xmlSetProp(child, BAD_CAST "calls", BAD_CAST buf);
+
+        sprintf(buf, "%ld", templates[i]->time);
+        xmlSetProp(child, BAD_CAST "time", BAD_CAST buf);
+
+        sprintf(buf, "%ld", templates[i]->time / templates[i]->nbCalls);
+        xmlSetProp(child, BAD_CAST "average", BAD_CAST buf);
+    };
+
+    xmlFree(templates);
+
+    return ret;
+}
+
 /************************************************************************
  * 									*
  * 		Hooks for the debugger					*
@@ -1541,7 +1721,7 @@ static xsltDebuggerCallbacks xsltDebuggerCurrentCallbacks = {
 int xslDebugStatus;
 
 /**
- * xslSetDebuggerCallbacks:
+ * xsltSetDebuggerCallbacks:
  * @no : number of callbacks
  * @block : the block of callbacks
  * 
@@ -1603,7 +1783,7 @@ xslAddCall(xsltTemplatePtr templ, xmlNodePtr source)
 }
 
 /**
- * xslDropCall :
+ * xslDropCall:
  *
  * Drop the topmost item off the call stack
  */
@@ -1614,3 +1794,4 @@ xslDropCall(void)
 	xsltDebuggerCurrentCallbacks.drop();
 }
 
+
